@@ -49,13 +49,19 @@ unary = [operator.neg, operator.abs, np.sin, np.tan, np.cos, np.arcsin,
 
 class Parameters(UserList):
     """
-    A collection of Parameters
+    A sequence of Parameters
+
+    Parameters
+    ----------
+    data : sequence
+        A sequence of :class:`Parameter` or :class:`Parameters`
+    name : str
+        Name of this :class:`Parameters` instance
     """
-    def __init__(self, name=None, data=None):
+    def __init__(self, data=(), name=None):
         super(Parameters, self).__init__()
         self.name = name
-        if data is not None:
-            self.data = data
+        self.data.extend(data)
 
     def __getitem__(self, i):
         if type(i) is str:
@@ -81,7 +87,8 @@ class Parameters(UserList):
             self.data[i] = v
 
     def __repr__(self):
-        return "Parameters({name!r}, data={data!r})".format(**self.__dict__)
+        return ("Parameters(data={data!r},"
+                " name={name!r})".format(**self.__dict__))
 
     def __str__(self):
         s = list()
@@ -101,12 +108,15 @@ class Parameters(UserList):
                 yield str(el)
 
     def __contains__(self, item):
+        """
+        Does this instance contain a given :class:`Parameter`
+        """
         return id(item) in [id(p) for p in f_unique(flatten(self.data))]
 
     def __ior__(self, other):
         """
-        concatenate Parameter(s). You can concatenate Parameters with Parameter
-        or Parameters instances.
+        Concatenate Parameter(s). You can concatenate :class:`Parameters` with
+        :class:`Parameter` or :class:`Parameters` instances.
         """
         # self |= other
         if not (is_parameter(other) or is_parameters(other)):
@@ -117,8 +127,8 @@ class Parameters(UserList):
 
     def __or__(self, other):
         """
-        concatenate Parameter(s). You can concatenate Parameters with Parameter
-        or Parameters instances.
+        concatenate Parameter(s). You can concatenate :class:`Parameters` with
+        :class:`Parameter` or :class:`Parameters` instances.
         """
         # c = self | other
         if not (is_parameter(other) or is_parameters(other)):
@@ -129,17 +139,31 @@ class Parameters(UserList):
         return self
 
     def logp(self):
+        """
+        Calculates logp for all the parameters
+
+        Returns
+        -------
+        logp : float
+            Log probability for all the parameters
+        """
         # logp for all the parameters
         return np.sum([param.logp() for param in f_unique(flatten(self.data))
                        if param.vary])
 
     def __array__(self):
-        """Convert Parameters to array."""
+        """
+        Convert Parameters to an array containing their values.
+        """
         return np.array([float(p) for p
                          in flatten(self.data)])
 
     @property
     def pvals(self):
+        """
+        An array containing the values of all the :class:`Parameter` in this
+        object.
+        """
         return np.array(self)
 
     @pvals.setter
@@ -171,21 +195,55 @@ class Parameters(UserList):
         return len(self.flattened())
 
     def flattened(self, unique=False):
+        """
+        A list of all the :class:`Parameter` contained in this object,
+        including those contained within :class:`Parameters` at any depth.
+
+        Parameters
+        ----------
+        unique : bool
+            The list will only contain unique objects.
+
+        Returns
+        -------
+        params : list
+            A list of :class:`Parameter` contained in this object.
+
+        """
         if unique:
             return list(f_unique(flatten(self.data)))
         else:
             return list(flatten(self.data))
 
     def names(self):
+        """
+        Returns
+        -------
+        names : list
+            A list of all the names of all the :class:`Parameter` contained in
+            this object.
+        """
         return [param.name for param in flatten(self.data)]
 
     def nvary(self):
+        """
+        Returns
+        -------
+        nvary : int
+            The number of :class:`Parameter` contained in this object that are
+            allowed to vary.
+
+        """
         return np.sum([1 for param in f_unique(flatten(self.data))
                        if param.vary])
 
     def constrained_parameters(self):
         """
-        List of constrained parameters
+        Returns
+        -------
+        constrained_parameters : list
+            A list of unique :class:`Parameter` contained in this object that
+            have constraints.
         """
         return [param for param in f_unique(flatten(self.data))
                 if param.constraint is not None]
@@ -204,6 +262,58 @@ class Parameters(UserList):
         q.data = p
         return q
 
+    def pgen(self, ngen=1000, nburn=0, nthin=1):
+        """
+        Yield random parameter vectors from MCMC samples.
+
+        Parameters
+        ----------
+        ngen : int, optional
+            the number of samples to yield. The actual number of samples
+            yielded is `min(ngen, chain.size)`
+        nburn : int, optional
+            discard this many steps from the start of the chain
+        nthin : int, optional
+            only accept every `nthin` samples from the chain
+
+        Yields
+        ------
+        pvec : np.ndarray
+            A randomly chosen parameter vector
+
+        Notes
+        -----
+        The entire parameter vector is yielded, not only the varying
+        parameters. The reason for this is that some parameters may possess a
+        chain if they are not varying, because they are controlled by a
+        constraint.
+        """
+
+        # it's still possible to have chains, even if there are no varying
+        # parameters, if there are parameters that have constraints
+        # generate for all params that have chains.
+        chain_pars = [i for i, p in enumerate(self.flattened()) if
+                      p.chain is not None]
+
+        chains = np.array([np.ravel(param.chain[..., nburn::nthin]) for param
+                           in self.flattened()
+                           if param.chain is not None])
+
+        if len(chains) == 0 or np.size(chains, 1) == 0:
+            raise ValueError("There were no chains to sample from")
+
+        samples = np.arange(np.size(chains, 1))
+
+        choices = np.random.choice(samples,
+                                   size=(min(ngen, samples.size),),
+                                   replace=False)
+
+        template_array = np.array(self.flattened())
+
+        for choice in choices:
+            template_array[chain_pars] = chains[..., choice]
+            yield template_array
+
 
 class BaseParameter(object):
     __add__ = MAKE_BINARY(operator.add)
@@ -366,15 +476,36 @@ def possibly_create_parameter(value, name=''):
 
 
 class Parameter(BaseParameter):
+    """
+    Class for specifying a variable.
+
+    Parameters
+    ----------
+    value : float, optional
+        Numerical Parameter value.
+    name : str, optional
+        Name of the parameter.
+    bounds: `refnx.analysis.Bounds`, tuple, optional
+        Sets the bounds for the parameter. Either supply a
+        `refnx.analysis.Bounds` object (or one of its subclasses),
+        or a `(lower_bound, upper_bound)` tuple.
+    vary : bool, optional
+        Whether the Parameter is fixed during a fit.
+    constraint : expression, optional
+        Python expression used to constrain the value during the fit.
+    """
+
     def __init__(self, value=0., name=None, bounds=None, vary=False,
                  constraint=None):
         """
+        Class for specifying a variable.
+
         Parameters
         ----------
-        name : str, optional
-            Name of the parameter.
         value : float, optional
             Numerical Parameter value.
+        name : str, optional
+            Name of the parameter.
         bounds: `refnx.analysis.Bounds`, tuple, optional
             Sets the bounds for the parameter. Either supply a
             `refnx.analysis.Bounds` object (or one of its subclasses),
@@ -432,6 +563,9 @@ class Parameter(BaseParameter):
 
     @property
     def value(self):
+        """
+        The numeric value of the :class:`Parameter`
+        """
         if self._constraint is not None:
             retval = self._constraint._eval()
         else:
@@ -453,6 +587,9 @@ class Parameter(BaseParameter):
 
     @property
     def bounds(self):
+        """
+        The bounds placed on this :class:`Parameter`.
+        """
         return self._bounds
 
     @bounds.setter
@@ -468,13 +605,45 @@ class Parameter(BaseParameter):
             self._bounds = rv
 
     def valid(self, val):
+        """
+        The truth of whether a value would satisfy the bounds for this
+        parameter.
+
+        Parameters
+        ----------
+        val : float
+            A proposed value
+
+        Returns
+        -------
+        valid : bool
+            `np.isfinite(Parameter.logp(val))`
+        """
         return self.bounds.valid(val)
 
     def range(self, lower, upper):
+        """
+        Sets the lower and upper limits on the Parameter
+
+        Parameters
+        ----------
+        lower : float
+            lower bound
+        upper : float
+            upper bound
+
+        Returns
+        -------
+        None
+
+        """
         self.bounds = Interval(lower, upper)
 
     @property
     def vary(self):
+        """
+        Whether this :class:`Parameter` is allowed to vary
+        """
         return self._vary
 
     @vary.setter
@@ -505,7 +674,20 @@ class Parameter(BaseParameter):
 
     def setp(self, value=None, vary=None, bounds=None, constraint=None):
         """
-        Set several attributes of the parameter at once
+        Set several attributes of the parameter at once.
+
+        Parameters
+        ----------
+        value : float, optional
+            Numerical Parameter value.
+        vary : bool, optional
+            Whether the Parameter is fixed during a fit.
+        bounds: `refnx.analysis.Bounds`, tuple, optional
+            Sets the bounds for the parameter. Either supply a
+            `refnx.analysis.Bounds` object (or one of its subclasses),
+            or a `(lower_bound, upper_bound)` tuple.
+        constraint : expression, optional
+            Python expression used to constrain the value during the fit.
         """
         if value is not None:
             self.value = value
