@@ -1,13 +1,11 @@
-from __future__ import absolute_import
-
 from refnx.reflect.reflect_model import (ReflectModel, reflectivity,
                                          MixedReflectModel)
 from refnx.reflect.structure import (Structure, SLD, Slab, Component,
-                                     sld_profile)
+                                     sld_profile, Stack)
 from refnx.reflect.spline import Spline
 from refnx.reflect._lipid import LipidLeaflet
 from refnx._lib._testutils import PytestTester
-from refnx.reflect._app import gui
+from refnx.reflect._app import gui, main
 
 
 try:
